Struct ExtDataControlOfferV1
pub struct ExtDataControlOfferV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
offer to transfer data
A ext_data_control_offer represents a piece of data offered for transfer by another client (the source client). The offer describes the different MIME types that the data can be converted to and provides the mechanism for transferring the data directly from the source client.
See also the Request enum for this interface.
Implementations